"""Type stubs for FIREWALL category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .DoS_policy import DosPolicy, DosPolicyDictMode, DosPolicyObjectMode
    from .DoS_policy6 import DosPolicy6, DosPolicy6DictMode, DosPolicy6ObjectMode
    from .access_proxy import AccessProxy, AccessProxyDictMode, AccessProxyObjectMode
    from .access_proxy6 import AccessProxy6, AccessProxy6DictMode, AccessProxy6ObjectMode
    from .access_proxy_ssh_client_cert import AccessProxySshClientCert, AccessProxySshClientCertDictMode, AccessProxySshClientCertObjectMode
    from .access_proxy_virtual_host import AccessProxyVirtualHost, AccessProxyVirtualHostDictMode, AccessProxyVirtualHostObjectMode
    from .address import Address, AddressDictMode, AddressObjectMode
    from .address6 import Address6, Address6DictMode, Address6ObjectMode
    from .address6_template import Address6Template, Address6TemplateDictMode, Address6TemplateObjectMode
    from .addrgrp import Addrgrp, AddrgrpDictMode, AddrgrpObjectMode
    from .addrgrp6 import Addrgrp6, Addrgrp6DictMode, Addrgrp6ObjectMode
    from .auth_portal import AuthPortal, AuthPortalDictMode, AuthPortalObjectMode
    from .central_snat_map import CentralSnatMap, CentralSnatMapDictMode, CentralSnatMapObjectMode
    from .city import City, CityDictMode, CityObjectMode
    from .country import Country, CountryDictMode, CountryObjectMode
    from .decrypted_traffic_mirror import DecryptedTrafficMirror, DecryptedTrafficMirrorDictMode, DecryptedTrafficMirrorObjectMode
    from .dnstranslation import Dnstranslation, DnstranslationDictMode, DnstranslationObjectMode
    from .global_ import Global, GlobalDictMode, GlobalObjectMode
    from .identity_based_route import IdentityBasedRoute, IdentityBasedRouteDictMode, IdentityBasedRouteObjectMode
    from .interface_policy import InterfacePolicy, InterfacePolicyDictMode, InterfacePolicyObjectMode
    from .interface_policy6 import InterfacePolicy6, InterfacePolicy6DictMode, InterfacePolicy6ObjectMode
    from .internet_service import InternetService, InternetServiceDictMode, InternetServiceObjectMode
    from .internet_service_addition import InternetServiceAddition, InternetServiceAdditionDictMode, InternetServiceAdditionObjectMode
    from .internet_service_append import InternetServiceAppend, InternetServiceAppendDictMode, InternetServiceAppendObjectMode
    from .internet_service_botnet import InternetServiceBotnet, InternetServiceBotnetDictMode, InternetServiceBotnetObjectMode
    from .internet_service_custom import InternetServiceCustom, InternetServiceCustomDictMode, InternetServiceCustomObjectMode
    from .internet_service_custom_group import InternetServiceCustomGroup, InternetServiceCustomGroupDictMode, InternetServiceCustomGroupObjectMode
    from .internet_service_definition import InternetServiceDefinition, InternetServiceDefinitionDictMode, InternetServiceDefinitionObjectMode
    from .internet_service_extension import InternetServiceExtension, InternetServiceExtensionDictMode, InternetServiceExtensionObjectMode
    from .internet_service_fortiguard import InternetServiceFortiguard, InternetServiceFortiguardDictMode, InternetServiceFortiguardObjectMode
    from .internet_service_group import InternetServiceGroup, InternetServiceGroupDictMode, InternetServiceGroupObjectMode
    from .internet_service_ipbl_reason import InternetServiceIpblReason, InternetServiceIpblReasonDictMode, InternetServiceIpblReasonObjectMode
    from .internet_service_ipbl_vendor import InternetServiceIpblVendor, InternetServiceIpblVendorDictMode, InternetServiceIpblVendorObjectMode
    from .internet_service_list import InternetServiceList, InternetServiceListDictMode, InternetServiceListObjectMode
    from .internet_service_name import InternetServiceName, InternetServiceNameDictMode, InternetServiceNameObjectMode
    from .internet_service_owner import InternetServiceOwner, InternetServiceOwnerDictMode, InternetServiceOwnerObjectMode
    from .internet_service_reputation import InternetServiceReputation, InternetServiceReputationDictMode, InternetServiceReputationObjectMode
    from .internet_service_sld import InternetServiceSld, InternetServiceSldDictMode, InternetServiceSldObjectMode
    from .internet_service_subapp import InternetServiceSubapp, InternetServiceSubappDictMode, InternetServiceSubappObjectMode
    from .ip_translation import IpTranslation, IpTranslationDictMode, IpTranslationObjectMode
    from .ippool import Ippool, IppoolDictMode, IppoolObjectMode
    from .ippool6 import Ippool6, Ippool6DictMode, Ippool6ObjectMode
    from .ldb_monitor import LdbMonitor, LdbMonitorDictMode, LdbMonitorObjectMode
    from .local_in_policy import LocalInPolicy, LocalInPolicyDictMode, LocalInPolicyObjectMode
    from .local_in_policy6 import LocalInPolicy6, LocalInPolicy6DictMode, LocalInPolicy6ObjectMode
    from .multicast_address import MulticastAddress, MulticastAddressDictMode, MulticastAddressObjectMode
    from .multicast_address6 import MulticastAddress6, MulticastAddress6DictMode, MulticastAddress6ObjectMode
    from .multicast_policy import MulticastPolicy, MulticastPolicyDictMode, MulticastPolicyObjectMode
    from .multicast_policy6 import MulticastPolicy6, MulticastPolicy6DictMode, MulticastPolicy6ObjectMode
    from .network_service_dynamic import NetworkServiceDynamic, NetworkServiceDynamicDictMode, NetworkServiceDynamicObjectMode
    from .on_demand_sniffer import OnDemandSniffer, OnDemandSnifferDictMode, OnDemandSnifferObjectMode
    from .policy import Policy, PolicyDictMode, PolicyObjectMode
    from .profile_group import ProfileGroup, ProfileGroupDictMode, ProfileGroupObjectMode
    from .profile_protocol_options import ProfileProtocolOptions, ProfileProtocolOptionsDictMode, ProfileProtocolOptionsObjectMode
    from .proxy_address import ProxyAddress, ProxyAddressDictMode, ProxyAddressObjectMode
    from .proxy_addrgrp import ProxyAddrgrp, ProxyAddrgrpDictMode, ProxyAddrgrpObjectMode
    from .proxy_policy import ProxyPolicy, ProxyPolicyDictMode, ProxyPolicyObjectMode
    from .region import Region, RegionDictMode, RegionObjectMode
    from .security_policy import SecurityPolicy, SecurityPolicyDictMode, SecurityPolicyObjectMode
    from .shaping_policy import ShapingPolicy, ShapingPolicyDictMode, ShapingPolicyObjectMode
    from .shaping_profile import ShapingProfile, ShapingProfileDictMode, ShapingProfileObjectMode
    from .sniffer import Sniffer, SnifferDictMode, SnifferObjectMode
    from .ssl_server import SslServer, SslServerDictMode, SslServerObjectMode
    from .ssl_ssh_profile import SslSshProfile, SslSshProfileDictMode, SslSshProfileObjectMode
    from .traffic_class import TrafficClass, TrafficClassDictMode, TrafficClassObjectMode
    from .ttl_policy import TtlPolicy, TtlPolicyDictMode, TtlPolicyObjectMode
    from .vendor_mac import VendorMac, VendorMacDictMode, VendorMacObjectMode
    from .vendor_mac_summary import VendorMacSummary, VendorMacSummaryDictMode, VendorMacSummaryObjectMode
    from .vip import Vip, VipDictMode, VipObjectMode
    from .vip6 import Vip6, Vip6DictMode, Vip6ObjectMode
    from .vipgrp import Vipgrp, VipgrpDictMode, VipgrpObjectMode
    from .vipgrp6 import Vipgrp6, Vipgrp6DictMode, Vipgrp6ObjectMode
    from .ipmacbinding import IpmacbindingDictMode, IpmacbindingObjectMode
    from .schedule import ScheduleDictMode, ScheduleObjectMode
    from .service import ServiceDictMode, ServiceObjectMode
    from .shaper import ShaperDictMode, ShaperObjectMode
    from .ssh import SshDictMode, SshObjectMode
    from .ssl import SslDictMode, SslObjectMode
    from .wildcard_fqdn import WildcardFqdn

__all__ = [
    "DosPolicy",
    "DosPolicy6",
    "AccessProxy",
    "AccessProxy6",
    "AccessProxySshClientCert",
    "AccessProxyVirtualHost",
    "Address",
    "Address6",
    "Address6Template",
    "Addrgrp",
    "Addrgrp6",
    "AuthPortal",
    "CentralSnatMap",
    "City",
    "Country",
    "DecryptedTrafficMirror",
    "Dnstranslation",
    "Global",
    "IdentityBasedRoute",
    "InterfacePolicy",
    "InterfacePolicy6",
    "InternetService",
    "InternetServiceAddition",
    "InternetServiceAppend",
    "InternetServiceBotnet",
    "InternetServiceCustom",
    "InternetServiceCustomGroup",
    "InternetServiceDefinition",
    "InternetServiceExtension",
    "InternetServiceFortiguard",
    "InternetServiceGroup",
    "InternetServiceIpblReason",
    "InternetServiceIpblVendor",
    "InternetServiceList",
    "InternetServiceName",
    "InternetServiceOwner",
    "InternetServiceReputation",
    "InternetServiceSld",
    "InternetServiceSubapp",
    "IpTranslation",
    "Ippool",
    "Ippool6",
    "LdbMonitor",
    "LocalInPolicy",
    "LocalInPolicy6",
    "MulticastAddress",
    "MulticastAddress6",
    "MulticastPolicy",
    "MulticastPolicy6",
    "NetworkServiceDynamic",
    "OnDemandSniffer",
    "Policy",
    "ProfileGroup",
    "ProfileProtocolOptions",
    "ProxyAddress",
    "ProxyAddrgrp",
    "ProxyPolicy",
    "Region",
    "SecurityPolicy",
    "ShapingPolicy",
    "ShapingProfile",
    "Sniffer",
    "SslServer",
    "SslSshProfile",
    "TrafficClass",
    "TtlPolicy",
    "VendorMac",
    "VendorMacSummary",
    "Vip",
    "Vip6",
    "Vipgrp",
    "Vipgrp6",
    "FirewallDictMode",
    "FirewallObjectMode",
]

class FirewallDictMode:
    """FIREWALL API category for dict response mode.
    
    This class is returned when the client is instantiated with response_mode="dict" (default).
    All endpoints return dict/TypedDict responses by default.
    """
    
    ipmacbinding: IpmacbindingDictMode
    schedule: ScheduleDictMode
    service: ServiceDictMode
    shaper: ShaperDictMode
    ssh: SshDictMode
    ssl: SslDictMode
    wildcard_fqdn: WildcardFqdn
    DoS_policy: DosPolicyDictMode
    DoS_policy6: DosPolicy6DictMode
    access_proxy: AccessProxyDictMode
    access_proxy6: AccessProxy6DictMode
    access_proxy_ssh_client_cert: AccessProxySshClientCertDictMode
    access_proxy_virtual_host: AccessProxyVirtualHostDictMode
    address: AddressDictMode
    address6: Address6DictMode
    address6_template: Address6TemplateDictMode
    addrgrp: AddrgrpDictMode
    addrgrp6: Addrgrp6DictMode
    auth_portal: AuthPortalDictMode
    central_snat_map: CentralSnatMapDictMode
    city: CityDictMode
    country: CountryDictMode
    decrypted_traffic_mirror: DecryptedTrafficMirrorDictMode
    dnstranslation: DnstranslationDictMode
    global_: GlobalDictMode
    identity_based_route: IdentityBasedRouteDictMode
    interface_policy: InterfacePolicyDictMode
    interface_policy6: InterfacePolicy6DictMode
    internet_service: InternetServiceDictMode
    internet_service_addition: InternetServiceAdditionDictMode
    internet_service_append: InternetServiceAppendDictMode
    internet_service_botnet: InternetServiceBotnetDictMode
    internet_service_custom: InternetServiceCustomDictMode
    internet_service_custom_group: InternetServiceCustomGroupDictMode
    internet_service_definition: InternetServiceDefinitionDictMode
    internet_service_extension: InternetServiceExtensionDictMode
    internet_service_fortiguard: InternetServiceFortiguardDictMode
    internet_service_group: InternetServiceGroupDictMode
    internet_service_ipbl_reason: InternetServiceIpblReasonDictMode
    internet_service_ipbl_vendor: InternetServiceIpblVendorDictMode
    internet_service_list: InternetServiceListDictMode
    internet_service_name: InternetServiceNameDictMode
    internet_service_owner: InternetServiceOwnerDictMode
    internet_service_reputation: InternetServiceReputationDictMode
    internet_service_sld: InternetServiceSldDictMode
    internet_service_subapp: InternetServiceSubappDictMode
    ip_translation: IpTranslationDictMode
    ippool: IppoolDictMode
    ippool6: Ippool6DictMode
    ldb_monitor: LdbMonitorDictMode
    local_in_policy: LocalInPolicyDictMode
    local_in_policy6: LocalInPolicy6DictMode
    multicast_address: MulticastAddressDictMode
    multicast_address6: MulticastAddress6DictMode
    multicast_policy: MulticastPolicyDictMode
    multicast_policy6: MulticastPolicy6DictMode
    network_service_dynamic: NetworkServiceDynamicDictMode
    on_demand_sniffer: OnDemandSnifferDictMode
    policy: PolicyDictMode
    profile_group: ProfileGroupDictMode
    profile_protocol_options: ProfileProtocolOptionsDictMode
    proxy_address: ProxyAddressDictMode
    proxy_addrgrp: ProxyAddrgrpDictMode
    proxy_policy: ProxyPolicyDictMode
    region: RegionDictMode
    security_policy: SecurityPolicyDictMode
    shaping_policy: ShapingPolicyDictMode
    shaping_profile: ShapingProfileDictMode
    sniffer: SnifferDictMode
    ssl_server: SslServerDictMode
    ssl_ssh_profile: SslSshProfileDictMode
    traffic_class: TrafficClassDictMode
    ttl_policy: TtlPolicyDictMode
    vendor_mac: VendorMacDictMode
    vendor_mac_summary: VendorMacSummaryDictMode
    vip: VipDictMode
    vip6: Vip6DictMode
    vipgrp: VipgrpDictMode
    vipgrp6: Vipgrp6DictMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize firewall category with HTTP client."""
        ...


class FirewallObjectMode:
    """FIREWALL API category for object response mode.
    
    This class is returned when the client is instantiated with response_mode="object".
    All endpoints return FortiObject responses by default.
    """
    
    ipmacbinding: IpmacbindingObjectMode
    schedule: ScheduleObjectMode
    service: ServiceObjectMode
    shaper: ShaperObjectMode
    ssh: SshObjectMode
    ssl: SslObjectMode
    wildcard_fqdn: WildcardFqdn
    DoS_policy: DosPolicyObjectMode
    DoS_policy6: DosPolicy6ObjectMode
    access_proxy: AccessProxyObjectMode
    access_proxy6: AccessProxy6ObjectMode
    access_proxy_ssh_client_cert: AccessProxySshClientCertObjectMode
    access_proxy_virtual_host: AccessProxyVirtualHostObjectMode
    address: AddressObjectMode
    address6: Address6ObjectMode
    address6_template: Address6TemplateObjectMode
    addrgrp: AddrgrpObjectMode
    addrgrp6: Addrgrp6ObjectMode
    auth_portal: AuthPortalObjectMode
    central_snat_map: CentralSnatMapObjectMode
    city: CityObjectMode
    country: CountryObjectMode
    decrypted_traffic_mirror: DecryptedTrafficMirrorObjectMode
    dnstranslation: DnstranslationObjectMode
    global_: GlobalObjectMode
    identity_based_route: IdentityBasedRouteObjectMode
    interface_policy: InterfacePolicyObjectMode
    interface_policy6: InterfacePolicy6ObjectMode
    internet_service: InternetServiceObjectMode
    internet_service_addition: InternetServiceAdditionObjectMode
    internet_service_append: InternetServiceAppendObjectMode
    internet_service_botnet: InternetServiceBotnetObjectMode
    internet_service_custom: InternetServiceCustomObjectMode
    internet_service_custom_group: InternetServiceCustomGroupObjectMode
    internet_service_definition: InternetServiceDefinitionObjectMode
    internet_service_extension: InternetServiceExtensionObjectMode
    internet_service_fortiguard: InternetServiceFortiguardObjectMode
    internet_service_group: InternetServiceGroupObjectMode
    internet_service_ipbl_reason: InternetServiceIpblReasonObjectMode
    internet_service_ipbl_vendor: InternetServiceIpblVendorObjectMode
    internet_service_list: InternetServiceListObjectMode
    internet_service_name: InternetServiceNameObjectMode
    internet_service_owner: InternetServiceOwnerObjectMode
    internet_service_reputation: InternetServiceReputationObjectMode
    internet_service_sld: InternetServiceSldObjectMode
    internet_service_subapp: InternetServiceSubappObjectMode
    ip_translation: IpTranslationObjectMode
    ippool: IppoolObjectMode
    ippool6: Ippool6ObjectMode
    ldb_monitor: LdbMonitorObjectMode
    local_in_policy: LocalInPolicyObjectMode
    local_in_policy6: LocalInPolicy6ObjectMode
    multicast_address: MulticastAddressObjectMode
    multicast_address6: MulticastAddress6ObjectMode
    multicast_policy: MulticastPolicyObjectMode
    multicast_policy6: MulticastPolicy6ObjectMode
    network_service_dynamic: NetworkServiceDynamicObjectMode
    on_demand_sniffer: OnDemandSnifferObjectMode
    policy: PolicyObjectMode
    profile_group: ProfileGroupObjectMode
    profile_protocol_options: ProfileProtocolOptionsObjectMode
    proxy_address: ProxyAddressObjectMode
    proxy_addrgrp: ProxyAddrgrpObjectMode
    proxy_policy: ProxyPolicyObjectMode
    region: RegionObjectMode
    security_policy: SecurityPolicyObjectMode
    shaping_policy: ShapingPolicyObjectMode
    shaping_profile: ShapingProfileObjectMode
    sniffer: SnifferObjectMode
    ssl_server: SslServerObjectMode
    ssl_ssh_profile: SslSshProfileObjectMode
    traffic_class: TrafficClassObjectMode
    ttl_policy: TtlPolicyObjectMode
    vendor_mac: VendorMacObjectMode
    vendor_mac_summary: VendorMacSummaryObjectMode
    vip: VipObjectMode
    vip6: Vip6ObjectMode
    vipgrp: VipgrpObjectMode
    vipgrp6: Vipgrp6ObjectMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize firewall category with HTTP client."""
        ...


# Base class for backwards compatibility
class Firewall:
    """FIREWALL API category."""
    
    ipmacbinding: Ipmacbinding
    schedule: Schedule
    service: Service
    shaper: Shaper
    ssh: Ssh
    ssl: Ssl
    wildcard_fqdn: WildcardFqdn
    DoS_policy: DosPolicy
    DoS_policy6: DosPolicy6
    access_proxy: AccessProxy
    access_proxy6: AccessProxy6
    access_proxy_ssh_client_cert: AccessProxySshClientCert
    access_proxy_virtual_host: AccessProxyVirtualHost
    address: Address
    address6: Address6
    address6_template: Address6Template
    addrgrp: Addrgrp
    addrgrp6: Addrgrp6
    auth_portal: AuthPortal
    central_snat_map: CentralSnatMap
    city: City
    country: Country
    decrypted_traffic_mirror: DecryptedTrafficMirror
    dnstranslation: Dnstranslation
    global_: Global
    identity_based_route: IdentityBasedRoute
    interface_policy: InterfacePolicy
    interface_policy6: InterfacePolicy6
    internet_service: InternetService
    internet_service_addition: InternetServiceAddition
    internet_service_append: InternetServiceAppend
    internet_service_botnet: InternetServiceBotnet
    internet_service_custom: InternetServiceCustom
    internet_service_custom_group: InternetServiceCustomGroup
    internet_service_definition: InternetServiceDefinition
    internet_service_extension: InternetServiceExtension
    internet_service_fortiguard: InternetServiceFortiguard
    internet_service_group: InternetServiceGroup
    internet_service_ipbl_reason: InternetServiceIpblReason
    internet_service_ipbl_vendor: InternetServiceIpblVendor
    internet_service_list: InternetServiceList
    internet_service_name: InternetServiceName
    internet_service_owner: InternetServiceOwner
    internet_service_reputation: InternetServiceReputation
    internet_service_sld: InternetServiceSld
    internet_service_subapp: InternetServiceSubapp
    ip_translation: IpTranslation
    ippool: Ippool
    ippool6: Ippool6
    ldb_monitor: LdbMonitor
    local_in_policy: LocalInPolicy
    local_in_policy6: LocalInPolicy6
    multicast_address: MulticastAddress
    multicast_address6: MulticastAddress6
    multicast_policy: MulticastPolicy
    multicast_policy6: MulticastPolicy6
    network_service_dynamic: NetworkServiceDynamic
    on_demand_sniffer: OnDemandSniffer
    policy: Policy
    profile_group: ProfileGroup
    profile_protocol_options: ProfileProtocolOptions
    proxy_address: ProxyAddress
    proxy_addrgrp: ProxyAddrgrp
    proxy_policy: ProxyPolicy
    region: Region
    security_policy: SecurityPolicy
    shaping_policy: ShapingPolicy
    shaping_profile: ShapingProfile
    sniffer: Sniffer
    ssl_server: SslServer
    ssl_ssh_profile: SslSshProfile
    traffic_class: TrafficClass
    ttl_policy: TtlPolicy
    vendor_mac: VendorMac
    vendor_mac_summary: VendorMacSummary
    vip: Vip
    vip6: Vip6
    vipgrp: Vipgrp
    vipgrp6: Vipgrp6

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize firewall category with HTTP client."""
        ...



"""FortiOS CMDB - Ipam category"""

from .list import List
from .status import Status
from .utilization import Utilization

__all__ = [
    "Ipam",
    "List",
    "Status",
    "Utilization",
]


class Ipam:
    """Ipam endpoints wrapper for CMDB API."""

    def __init__(self, client):
        """Ipam endpoints.
        
        Args:
            client: HTTP client instance for API communication
        """
        self.list = List(client)
        self.status = Status(client)
        self.utilization = Utilization(client)



"""
Pydantic Models for CMDB - wireless_controller/hotspot20/anqp_ip_address_type

Runtime validation models for wireless_controller/hotspot20/anqp_ip_address_type configuration.
Generated from FortiOS schema version unknown.

Example Usage:
    >>> from hfortix_fortios.models.cmdb.wireless_controller.hotspot20.anqp_ip_address_type import 
    >>>
    >>> # Create with validation
    >>> obj = (
    ...     name=1,
    ...     name="example",
    ... )
    >>>
    >>> # Validation happens automatically
    >>> # ValidationError raised if constraints violated
"""

from __future__ import annotations

from pydantic import BaseModel, Field, field_validator
from typing import Any, Literal, Optional
from enum import Enum

# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================

class AnqpIpAddressTypeIpv4_address_typeEnum(str, Enum):
    """Allowed values for ipv4_address_type field."""
    NOT_AVAILABLE = "not-available"    PUBLIC = "public"    PORT_RESTRICTED = "port-restricted"    SINGLE_NATED_PRIVATE = "single-NATed-private"    DOUBLE_NATED_PRIVATE = "double-NATed-private"    PORT_RESTRICTED_AND_SINGLE_NATED = "port-restricted-and-single-NATed"    PORT_RESTRICTED_AND_DOUBLE_NATED = "port-restricted-and-double-NATed"    NOT_KNOWN = "not-known"

# ============================================================================
# Main Model
# ============================================================================

class AnqpIpAddressTypeModel(BaseModel):
    """
    Pydantic model for wireless_controller/hotspot20/anqp_ip_address_type configuration.
    
    Configure IP address type availability.
    
    Validation Rules:        - name: max_length=35 pattern=        - ipv6_address_type: pattern=        - ipv4_address_type: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    name: str | None = Field(max_length=35, default="", description="IP type name.")    
    ipv6_address_type: Literal["not-available", "available", "not-known"] | None = Field(default="not-available", description="IPv6 address type.")    
    ipv4_address_type: Ipv4AddressTypeEnum | None = Field(default="not-available", description="IPv4 address type.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "AnqpIpAddressTypeModel",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.0
# Generated: 2026-01-09T09:47:42.724725Z
# ============================================================================


"""Type stubs for IPAM category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .list import List, ListDictMode, ListObjectMode
    from .status import Status, StatusDictMode, StatusObjectMode
    from .utilization import Utilization, UtilizationDictMode, UtilizationObjectMode

__all__ = [
    "List",
    "Status",
    "Utilization",
    "IpamDictMode",
    "IpamObjectMode",
]

class IpamDictMode:
    """IPAM API category for dict response mode.
    
    This class is returned when the client is instantiated with response_mode="dict" (default).
    All endpoints return dict/TypedDict responses by default.
    """
    
    list: ListDictMode
    status: StatusDictMode
    utilization: UtilizationDictMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize ipam category with HTTP client."""
        ...


class IpamObjectMode:
    """IPAM API category for object response mode.
    
    This class is returned when the client is instantiated with response_mode="object".
    All endpoints return FortiObject responses by default.
    """
    
    list: ListObjectMode
    status: StatusObjectMode
    utilization: UtilizationObjectMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize ipam category with HTTP client."""
        ...


# Base class for backwards compatibility
class Ipam:
    """IPAM API category."""
    
    list: List
    status: Status
    utilization: Utilization

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize ipam category with HTTP client."""
        ...



from typing import TypedDict, Literal, NotRequired, Any, Coroutine, Union, overload, Generator, final
from hfortix_fortios.models import FortiObject
from hfortix_core.types import MutationResponse, RawAPIResponse

# Payload TypedDict for IDE autocomplete (for POST/PUT - fields are optional via total=False)
# NOTE: We intentionally DON'T use NotRequired wrapper because:
# 1. total=False already makes all fields optional
# 2. NotRequired[Literal[...]] prevents Pylance from validating Literal values in dict literals
class TimersPayload(TypedDict, total=False):
    """
    Type hints for wireless_controller/timers payload fields.
    
    Configure CAPWAP timers.
    
    **Usage:**
        payload: TimersPayload = {
            "field": "value",  # <- autocomplete shows all fields
        }
    """
    echo_interval: int  # Time between echo requests sent by the managed WTP | Default: 30 | Min: 1 | Max: 255
    nat_session_keep_alive: int  # Maximal time in seconds between control requests s | Default: 0 | Min: 0 | Max: 255
    discovery_interval: int  # Time between discovery requests | Default: 5 | Min: 2 | Max: 180
    client_idle_timeout: int  # Time after which a client is considered idle and t | Default: 300 | Min: 20 | Max: 3600
    client_idle_rehome_timeout: int  # Time after which a client is considered idle and d | Default: 20 | Min: 2 | Max: 3600
    auth_timeout: int  # Time after which a client is considered failed in | Default: 5 | Min: 5 | Max: 30
    rogue_ap_log: int  # Time between logging rogue AP messages if periodic | Default: 0 | Min: 0 | Max: 1440
    fake_ap_log: int  # Time between recording logs about fake APs if peri | Default: 1 | Min: 1 | Max: 1440
    sta_offline_cleanup: int  # Time period in seconds to keep station offline dat | Default: 300 | Min: 0 | Max: 4294967295
    sta_offline_ip2mac_cleanup: int  # Time period in seconds to keep station offline Ip2 | Default: 300 | Min: 0 | Max: 4294967295
    sta_cap_cleanup: int  # Time period in minutes to keep station capability | Default: 0 | Min: 0 | Max: 4294967295
    rogue_ap_cleanup: int  # Time period in minutes to keep rogue AP after it i | Default: 0 | Min: 0 | Max: 4294967295
    rogue_sta_cleanup: int  # Time period in minutes to keep rogue station after | Default: 0 | Min: 0 | Max: 4294967295
    wids_entry_cleanup: int  # Time period in minutes to keep wids entry after it | Default: 0 | Min: 0 | Max: 4294967295
    ble_device_cleanup: int  # Time period in minutes to keep BLE device after it | Default: 60 | Min: 0 | Max: 4294967295
    sta_stats_interval: int  # Time between running client (station) reports | Default: 10 | Min: 1 | Max: 255
    vap_stats_interval: int  # Time between running Virtual Access Point (VAP) re | Default: 15 | Min: 1 | Max: 255
    radio_stats_interval: int  # Time between running radio reports | Default: 15 | Min: 1 | Max: 255
    sta_capability_interval: int  # Time between running station capability reports | Default: 30 | Min: 1 | Max: 255
    sta_locate_timer: int  # Time between running client presence flushes to re | Default: 1800 | Min: 0 | Max: 86400
    ipsec_intf_cleanup: int  # Time period to keep IPsec VPN interfaces up after | Default: 120 | Min: 30 | Max: 3600
    ble_scan_report_intv: int  # Time between running Bluetooth Low Energy (BLE) re | Default: 30 | Min: 10 | Max: 3600
    drma_interval: int  # Dynamic radio mode assignment (DRMA) schedule inte | Default: 60 | Min: 1 | Max: 1440
    ap_reboot_wait_interval1: int  # Time in minutes to wait before AP reboots when the | Default: 0 | Min: 5 | Max: 65535
    ap_reboot_wait_time: str  # Time to reboot the AP when there is no controller | MaxLen: 7
    ap_reboot_wait_interval2: int  # Time in minutes to wait before AP reboots when the | Default: 0 | Min: 5 | Max: 65535

# Nested TypedDicts for table field children (dict mode)

# Nested classes for table field children (object mode)


# Response TypedDict for GET returns (all fields present in API response)
class TimersResponse(TypedDict):
    """
    Type hints for wireless_controller/timers API response fields.
    
    All fields are present in the response from the FortiGate API.
    """
    echo_interval: int  # Time between echo requests sent by the managed WTP | Default: 30 | Min: 1 | Max: 255
    nat_session_keep_alive: int  # Maximal time in seconds between control requests s | Default: 0 | Min: 0 | Max: 255
    discovery_interval: int  # Time between discovery requests | Default: 5 | Min: 2 | Max: 180
    client_idle_timeout: int  # Time after which a client is considered idle and t | Default: 300 | Min: 20 | Max: 3600
    client_idle_rehome_timeout: int  # Time after which a client is considered idle and d | Default: 20 | Min: 2 | Max: 3600
    auth_timeout: int  # Time after which a client is considered failed in | Default: 5 | Min: 5 | Max: 30
    rogue_ap_log: int  # Time between logging rogue AP messages if periodic | Default: 0 | Min: 0 | Max: 1440
    fake_ap_log: int  # Time between recording logs about fake APs if peri | Default: 1 | Min: 1 | Max: 1440
    sta_offline_cleanup: int  # Time period in seconds to keep station offline dat | Default: 300 | Min: 0 | Max: 4294967295
    sta_offline_ip2mac_cleanup: int  # Time period in seconds to keep station offline Ip2 | Default: 300 | Min: 0 | Max: 4294967295
    sta_cap_cleanup: int  # Time period in minutes to keep station capability | Default: 0 | Min: 0 | Max: 4294967295
    rogue_ap_cleanup: int  # Time period in minutes to keep rogue AP after it i | Default: 0 | Min: 0 | Max: 4294967295
    rogue_sta_cleanup: int  # Time period in minutes to keep rogue station after | Default: 0 | Min: 0 | Max: 4294967295
    wids_entry_cleanup: int  # Time period in minutes to keep wids entry after it | Default: 0 | Min: 0 | Max: 4294967295
    ble_device_cleanup: int  # Time period in minutes to keep BLE device after it | Default: 60 | Min: 0 | Max: 4294967295
    sta_stats_interval: int  # Time between running client (station) reports | Default: 10 | Min: 1 | Max: 255
    vap_stats_interval: int  # Time between running Virtual Access Point (VAP) re | Default: 15 | Min: 1 | Max: 255
    radio_stats_interval: int  # Time between running radio reports | Default: 15 | Min: 1 | Max: 255
    sta_capability_interval: int  # Time between running station capability reports | Default: 30 | Min: 1 | Max: 255
    sta_locate_timer: int  # Time between running client presence flushes to re | Default: 1800 | Min: 0 | Max: 86400
    ipsec_intf_cleanup: int  # Time period to keep IPsec VPN interfaces up after | Default: 120 | Min: 30 | Max: 3600
    ble_scan_report_intv: int  # Time between running Bluetooth Low Energy (BLE) re | Default: 30 | Min: 10 | Max: 3600
    drma_interval: int  # Dynamic radio mode assignment (DRMA) schedule inte | Default: 60 | Min: 1 | Max: 1440
    ap_reboot_wait_interval1: int  # Time in minutes to wait before AP reboots when the | Default: 0 | Min: 5 | Max: 65535
    ap_reboot_wait_time: str  # Time to reboot the AP when there is no controller | MaxLen: 7
    ap_reboot_wait_interval2: int  # Time in minutes to wait before AP reboots when the | Default: 0 | Min: 5 | Max: 65535


@final
class TimersObject:
    """Typed FortiObject for wireless_controller/timers with IDE autocomplete support.
    
    This is a typed wrapper that provides IDE autocomplete for API response fields.
    At runtime, this is actually a FortiObject instance.
    """
    
    # Time between echo requests sent by the managed WTP, AP, or F | Default: 30 | Min: 1 | Max: 255
    echo_interval: int
    # Maximal time in seconds between control requests sent by the | Default: 0 | Min: 0 | Max: 255
    nat_session_keep_alive: int
    # Time between discovery requests (2 - 180 sec, default = 5). | Default: 5 | Min: 2 | Max: 180
    discovery_interval: int
    # Time after which a client is considered idle and times out | Default: 300 | Min: 20 | Max: 3600
    client_idle_timeout: int
    # Time after which a client is considered idle and disconnecte | Default: 20 | Min: 2 | Max: 3600
    client_idle_rehome_timeout: int
    # Time after which a client is considered failed in RADIUS aut | Default: 5 | Min: 5 | Max: 30
    auth_timeout: int
    # Time between logging rogue AP messages if periodic rogue AP | Default: 0 | Min: 0 | Max: 1440
    rogue_ap_log: int
    # Time between recording logs about fake APs if periodic fake | Default: 1 | Min: 1 | Max: 1440
    fake_ap_log: int
    # Time period in seconds to keep station offline data after it | Default: 300 | Min: 0 | Max: 4294967295
    sta_offline_cleanup: int
    # Time period in seconds to keep station offline Ip2mac data a | Default: 300 | Min: 0 | Max: 4294967295
    sta_offline_ip2mac_cleanup: int
    # Time period in minutes to keep station capability data after | Default: 0 | Min: 0 | Max: 4294967295
    sta_cap_cleanup: int
    # Time period in minutes to keep rogue AP after it is gone | Default: 0 | Min: 0 | Max: 4294967295
    rogue_ap_cleanup: int
    # Time period in minutes to keep rogue station after it is gon | Default: 0 | Min: 0 | Max: 4294967295
    rogue_sta_cleanup: int
    # Time period in minutes to keep wids entry after it is gone | Default: 0 | Min: 0 | Max: 4294967295
    wids_entry_cleanup: int
    # Time period in minutes to keep BLE device after it is gone | Default: 60 | Min: 0 | Max: 4294967295
    ble_device_cleanup: int
    # Time between running client (station) reports | Default: 10 | Min: 1 | Max: 255
    sta_stats_interval: int
    # Time between running Virtual Access Point (VAP) reports | Default: 15 | Min: 1 | Max: 255
    vap_stats_interval: int
    # Time between running radio reports | Default: 15 | Min: 1 | Max: 255
    radio_stats_interval: int
    # Time between running station capability reports | Default: 30 | Min: 1 | Max: 255
    sta_capability_interval: int
    # Time between running client presence flushes to remove clien | Default: 1800 | Min: 0 | Max: 86400
    sta_locate_timer: int
    # Time period to keep IPsec VPN interfaces up after WTP sessio | Default: 120 | Min: 30 | Max: 3600
    ipsec_intf_cleanup: int
    # Time between running Bluetooth Low Energy (BLE) reports | Default: 30 | Min: 10 | Max: 3600
    ble_scan_report_intv: int
    # Dynamic radio mode assignment (DRMA) schedule interval in mi | Default: 60 | Min: 1 | Max: 1440
    drma_interval: int
    # Time in minutes to wait before AP reboots when there is no c | Default: 0 | Min: 5 | Max: 65535
    ap_reboot_wait_interval1: int
    # Time to reboot the AP when there is no controller detected a | MaxLen: 7
    ap_reboot_wait_time: str
    # Time in minutes to wait before AP reboots when there is no c | Default: 0 | Min: 5 | Max: 65535
    ap_reboot_wait_interval2: int
    
    # Common API response fields
    status: str
    http_status: int | None
    vdom: str | None
    
    # Methods from FortiObject
    def get_full(self, name: str) -> Any: ...
    def to_dict(self) -> TimersPayload: ...
    def keys(self) -> Any: ...
    def values(self) -> Generator[Any, None, None]: ...
    def items(self) -> Generator[tuple[str, Any], None, None]: ...
    def get(self, key: str, default: Any = None) -> Any: ...
    def __getitem__(self, key: str) -> Any: ...


class Timers:
    """
    Configure CAPWAP timers.
    
    Path: wireless_controller/timers
    Category: cmdb
    """
    
    # ================================================================
    # DEFAULT MODE OVERLOADS (no response_mode) - MUST BE FIRST
    # These match when response_mode is NOT passed (client default is "dict")
    # Pylance matches overloads top-to-bottom, so these must come first!
    # ================================================================
    
    # Default mode: mkey as positional arg -> returns typed dict
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
    ) -> TimersResponse: ...
    
    # Default mode: mkey as keyword arg -> returns typed dict
    @overload
    def get(
        self,
        *,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
    ) -> TimersResponse: ...
    
    # Default mode: no mkey -> returns list of typed dicts
    @overload
    def get(
        self,
        name: None = None,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
    ) -> TimersResponse: ...
    
    # ================================================================
    # EXPLICIT response_mode="object" OVERLOADS
    # ================================================================
    
    # Object mode: mkey as positional arg -> returns single object
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> TimersObject: ...
    
    # Object mode: mkey as keyword arg -> returns single object
    @overload
    def get(
        self,
        *,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> TimersObject: ...
    
    # Object mode: no mkey -> returns list of objects
    @overload
    def get(
        self,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> TimersObject: ...
    
    # raw_json=True returns the full API envelope
    @overload
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[True] = ...,
        response_mode: Literal["object"] = ...,
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Dict mode with mkey provided as positional arg (single dict)
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] = ...,
        **kwargs: Any,
    ) -> TimersResponse: ...
    
    # Dict mode with mkey provided as keyword arg (single dict)
    @overload
    def get(
        self,
        *,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] = ...,
        **kwargs: Any,
    ) -> TimersResponse: ...
    
    # Dict mode - list of dicts (no mkey/name provided) - keyword-only signature
    @overload
    def get(
        self,
        *,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] = ...,
        **kwargs: Any,
    ) -> TimersResponse: ...
    
    # Fallback overload for all other cases
    @overload
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict", "object"] | None = ...,
        **kwargs: Any,
    ) -> dict[str, Any] | FortiObject: ...
    
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: str | None = ...,
        **kwargs: Any,
    ) -> TimersObject | dict[str, Any]: ...
    
    def get_schema(
        self,
        vdom: str | None = ...,
        format: str = ...,
    ) -> dict[str, Any]: ...
    
    # PUT overloads
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> TimersObject: ...
    
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[False] = ...,
        response_mode: Literal["dict"] | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # raw_json=True returns the full API envelope
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        raw_json: Literal[True] = ...,
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Default overload (no response_mode or raw_json specified)
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict", "object"] | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    def exists(
        self,
        name: str,
        vdom: str | bool | None = ...,
    ) -> bool: ...
    
    def set(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict", "object"] | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # Helper methods
    @staticmethod
    def help(field_name: str | None = ...) -> str: ...
    
    @staticmethod
    def fields(detailed: bool = ...) -> Union[list[str], list[dict[str, Any]]]: ...
    
    @staticmethod
    def field_info(field_name: str) -> dict[str, Any]: ...
    
    @staticmethod
    def validate_field(name: str, value: Any) -> bool: ...
    
    @staticmethod
    def required_fields() -> list[str]: ...
    
    @staticmethod
    def defaults() -> dict[str, Any]: ...
    
    @staticmethod
    def schema() -> dict[str, Any]: ...


# ================================================================
# MODE-SPECIFIC CLASSES FOR CLIENT-LEVEL response_mode SUPPORT
# ================================================================

class TimersDictMode:
    """Timers endpoint for dict response mode (default for this client).
    
    By default returns TimersResponse (TypedDict).
    Can be overridden per-call with response_mode="object" to return TimersObject.
    """
    
    # raw_json=True returns RawAPIResponse regardless of response_mode
    @overload
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Object mode override with mkey (single item)
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> TimersObject: ...
    
    # Object mode override without mkey (list)
    @overload
    def get(
        self,
        name: None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> TimersObject: ...
    
    # Dict mode with mkey (single item) - default
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict"] | None = ...,
        **kwargs: Any,
    ) -> TimersResponse: ...
    
    # Dict mode without mkey (list) - default
    @overload
    def get(
        self,
        name: None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["dict"] | None = ...,
        **kwargs: Any,
    ) -> TimersResponse: ...


    # raw_json=True returns RawAPIResponse for PUT
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # PUT - Object mode override
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> TimersObject: ...
    
    # PUT - Default overload (returns MutationResponse)
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # PUT - Dict mode (default for DictMode class)
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...



class TimersObjectMode:
    """Timers endpoint for object response mode (default for this client).
    
    By default returns TimersObject (FortiObject).
    Can be overridden per-call with response_mode="dict" to return TimersResponse (TypedDict).
    """
    
    # raw_json=True returns RawAPIResponse for GET
    @overload
    def get(
        self,
        name: str | None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # Dict mode override with mkey (single item)
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        *,
        response_mode: Literal["dict"],
        **kwargs: Any,
    ) -> TimersResponse: ...
    
    # Dict mode override without mkey (list)
    @overload
    def get(
        self,
        name: None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        *,
        response_mode: Literal["dict"],
        **kwargs: Any,
    ) -> TimersResponse: ...
    
    # Object mode with mkey (single item) - default
    @overload
    def get(
        self,
        name: str,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["object"] | None = ...,
        **kwargs: Any,
    ) -> TimersObject: ...
    
    # Object mode without mkey (list) - default
    @overload
    def get(
        self,
        name: None = ...,
        filter: str | list[str] | None = ...,
        count: int | None = ...,
        start: int | None = ...,
        payload_dict: dict[str, Any] | None = ...,
        range: list[int] | None = ...,
        sort: str | None = ...,
        format: str | None = ...,
        action: str | None = ...,
        vdom: str | bool | None = ...,
        raw_json: bool = ...,
        response_mode: Literal["object"] | None = ...,
        **kwargs: Any,
    ) -> TimersObject: ...


    # PUT - Dict mode override
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["dict"],
        **kwargs: Any,
    ) -> MutationResponse: ...
    
    # raw_json=True returns RawAPIResponse for PUT
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        *,
        raw_json: Literal[True],
        **kwargs: Any,
    ) -> RawAPIResponse: ...
    
    # PUT - Object mode override (requires explicit response_mode="object")
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        *,
        response_mode: Literal["object"],
        **kwargs: Any,
    ) -> TimersObject: ...
    
    # PUT - Default overload (no response_mode specified, returns Object for ObjectMode)
    @overload
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> TimersObject: ...
    
    # PUT - Default for ObjectMode (returns MutationResponse like DictMode)
    def put(
        self,
        payload_dict: TimersPayload | None = ...,
        echo_interval: int | None = ...,
        nat_session_keep_alive: int | None = ...,
        discovery_interval: int | None = ...,
        client_idle_timeout: int | None = ...,
        client_idle_rehome_timeout: int | None = ...,
        auth_timeout: int | None = ...,
        rogue_ap_log: int | None = ...,
        fake_ap_log: int | None = ...,
        sta_offline_cleanup: int | None = ...,
        sta_offline_ip2mac_cleanup: int | None = ...,
        sta_cap_cleanup: int | None = ...,
        rogue_ap_cleanup: int | None = ...,
        rogue_sta_cleanup: int | None = ...,
        wids_entry_cleanup: int | None = ...,
        ble_device_cleanup: int | None = ...,
        sta_stats_interval: int | None = ...,
        vap_stats_interval: int | None = ...,
        radio_stats_interval: int | None = ...,
        sta_capability_interval: int | None = ...,
        sta_locate_timer: int | None = ...,
        ipsec_intf_cleanup: int | None = ...,
        ble_scan_report_intv: int | None = ...,
        drma_interval: int | None = ...,
        ap_reboot_wait_interval1: int | None = ...,
        ap_reboot_wait_time: str | None = ...,
        ap_reboot_wait_interval2: int | None = ...,
        vdom: str | bool | None = ...,
        **kwargs: Any,
    ) -> MutationResponse: ...



__all__ = [
    "Timers",
    "TimersDictMode",
    "TimersObjectMode",
    "TimersPayload",
    "TimersObject",
]


"""Type stubs for CERTIFICATE category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .ca import Ca, CaDictMode, CaObjectMode
    from .crl import Crl, CrlDictMode, CrlObjectMode
    from .hsm_local import HsmLocal, HsmLocalDictMode, HsmLocalObjectMode
    from .local import Local, LocalDictMode, LocalObjectMode
    from .ocsp_server import OcspServer, OcspServerDictMode, OcspServerObjectMode
    from .remote import Remote, RemoteDictMode, RemoteObjectMode
    from .setting import Setting, SettingDictMode, SettingObjectMode

__all__ = [
    "Ca",
    "Crl",
    "HsmLocal",
    "Local",
    "OcspServer",
    "Remote",
    "Setting",
    "CertificateDictMode",
    "CertificateObjectMode",
]

class CertificateDictMode:
    """CERTIFICATE API category for dict response mode.
    
    This class is returned when the client is instantiated with response_mode="dict" (default).
    All endpoints return dict/TypedDict responses by default.
    """
    
    ca: CaDictMode
    crl: CrlDictMode
    hsm_local: HsmLocalDictMode
    local: LocalDictMode
    ocsp_server: OcspServerDictMode
    remote: RemoteDictMode
    setting: SettingDictMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize certificate category with HTTP client."""
        ...


class CertificateObjectMode:
    """CERTIFICATE API category for object response mode.
    
    This class is returned when the client is instantiated with response_mode="object".
    All endpoints return FortiObject responses by default.
    """
    
    ca: CaObjectMode
    crl: CrlObjectMode
    hsm_local: HsmLocalObjectMode
    local: LocalObjectMode
    ocsp_server: OcspServerObjectMode
    remote: RemoteObjectMode
    setting: SettingObjectMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize certificate category with HTTP client."""
        ...


# Base class for backwards compatibility
class Certificate:
    """CERTIFICATE API category."""
    
    ca: Ca
    crl: Crl
    hsm_local: HsmLocal
    local: Local
    ocsp_server: OcspServer
    remote: Remote
    setting: Setting

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize certificate category with HTTP client."""
        ...



"""Type stubs for CRL category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .import_ import Import, ImportDictMode, ImportObjectMode

__all__ = [
    "Import",
    "CrlDictMode",
    "CrlObjectMode",
]

class CrlDictMode:
    """CRL API category for dict response mode.
    
    This class is returned when the client is instantiated with response_mode="dict" (default).
    All endpoints return dict/TypedDict responses by default.
    """
    
    import_: ImportDictMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize crl category with HTTP client."""
        ...


class CrlObjectMode:
    """CRL API category for object response mode.
    
    This class is returned when the client is instantiated with response_mode="object".
    All endpoints return FortiObject responses by default.
    """
    
    import_: ImportObjectMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize crl category with HTTP client."""
        ...


# Base class for backwards compatibility
class Crl:
    """CRL API category."""
    
    import_: Import

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize crl category with HTTP client."""
        ...



"""Type stubs for RULE category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .fmwp import Fmwp, FmwpDictMode, FmwpObjectMode
    from .iotd import Iotd, IotdDictMode, IotdObjectMode
    from .otdt import Otdt, OtdtDictMode, OtdtObjectMode
    from .otvp import Otvp, OtvpDictMode, OtvpObjectMode

__all__ = [
    "Fmwp",
    "Iotd",
    "Otdt",
    "Otvp",
    "RuleDictMode",
    "RuleObjectMode",
]

class RuleDictMode:
    """RULE API category for dict response mode.
    
    This class is returned when the client is instantiated with response_mode="dict" (default).
    All endpoints return dict/TypedDict responses by default.
    """
    
    fmwp: FmwpDictMode
    iotd: IotdDictMode
    otdt: OtdtDictMode
    otvp: OtvpDictMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize rule category with HTTP client."""
        ...


class RuleObjectMode:
    """RULE API category for object response mode.
    
    This class is returned when the client is instantiated with response_mode="object".
    All endpoints return FortiObject responses by default.
    """
    
    fmwp: FmwpObjectMode
    iotd: IotdObjectMode
    otdt: OtdtObjectMode
    otvp: OtvpObjectMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize rule category with HTTP client."""
        ...


# Base class for backwards compatibility
class Rule:
    """RULE API category."""
    
    fmwp: Fmwp
    iotd: Iotd
    otdt: Otdt
    otvp: Otvp

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize rule category with HTTP client."""
        ...



"""
Pydantic Models for CMDB - web_proxy/profile

Runtime validation models for web_proxy/profile configuration.
Generated from FortiOS schema version unknown.

Example Usage:
    >>> from hfortix_fortios.models.cmdb.web_proxy.profile import 
    >>>
    >>> # Create with validation
    >>> obj = (
    ...     name=1,
    ...     name="example",
    ... )
    >>>
    >>> # Validation happens automatically
    >>> # ValidationError raised if constraints violated
"""

from __future__ import annotations

from pydantic import BaseModel, Field, field_validator
from typing import Any, Literal, Optional

# ============================================================================
# Child Table Models
# ============================================================================

class ProfileHeaders(BaseModel):
    """
    Child table model for headers.
    
    Configure HTTP forwarded requests headers.
    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
    
    id: int | None = Field(ge=0, le=4294967295, default=0, description="HTTP forwarded header id.")    
    name: str | None = Field(max_length=79, default="", description="HTTP forwarded header name.")    
    dstaddr: list[Dstaddr] = Field(default=None, description="Destination address and address group names.")    
    dstaddr6: list[Dstaddr6] = Field(default=None, description="Destination address and address group names (IPv6).")    
    action: ActionEnum | None = Field(default="add-to-request", description="Configure adding, removing, or logging of the HTTP header entry in HTTP requests and responses.")    
    content: str | None = Field(max_length=3999, default="", description="HTTP header content (max length: 3999 characters).")    
    base64_encoding: Literal["disable", "enable"] | None = Field(default="disable", description="Enable/disable use of base64 encoding of HTTP content.")    
    add_option: AddOptionEnum | None = Field(default="new", description="Configure options to append content to existing HTTP header or add new HTTP header.")    
    protocol: list[Protocol] = Field(default="https http", description="Configure protocol(s) to take add-option action on (HTTP, HTTPS, or both).")
# ============================================================================
# Enum Definitions (for fields with 4+ allowed values)
# ============================================================================


# ============================================================================
# Main Model
# ============================================================================

class ProfileModel(BaseModel):
    """
    Pydantic model for web_proxy/profile configuration.
    
    Configure web proxy profiles.
    
    Validation Rules:        - name: max_length=63 pattern=        - header_client_ip: pattern=        - header_via_request: pattern=        - header_via_response: pattern=        - header_client_cert: pattern=        - header_x_forwarded_for: pattern=        - header_x_forwarded_client_cert: pattern=        - header_front_end_https: pattern=        - header_x_authenticated_user: pattern=        - header_x_authenticated_groups: pattern=        - strip_encoding: pattern=        - log_header_change: pattern=        - headers: pattern=    """
    
    class Config:
        """Pydantic model configuration."""
        extra = "allow"  # Allow additional fields from API
        str_strip_whitespace = True
        validate_assignment = True  # Validate on attribute assignment
        use_enum_values = True  # Use enum values instead of names
    
    # ========================================================================
    # Model Fields
    # ========================================================================
    
    name: str | None = Field(max_length=63, default="", description="Profile name.")    
    header_client_ip: Literal["pass", "add", "remove"] | None = Field(default="pass", description="Action to take on the HTTP client-IP header in forwarded requests: forwards (pass), adds, or removes the HTTP header.")    
    header_via_request: Literal["pass", "add", "remove"] | None = Field(default="pass", description="Action to take on the HTTP via header in forwarded requests: forwards (pass), adds, or removes the HTTP header.")    
    header_via_response: Literal["pass", "add", "remove"] | None = Field(default="pass", description="Action to take on the HTTP via header in forwarded responses: forwards (pass), adds, or removes the HTTP header.")    
    header_client_cert: Literal["pass", "add", "remove"] | None = Field(default="pass", description="Action to take on the HTTP Client-Cert/Client-Cert-Chain headers in forwarded responses: forwards (pass), adds, or removes the HTTP header.")    
    header_x_forwarded_for: Literal["pass", "add", "remove"] | None = Field(default="pass", description="Action to take on the HTTP x-forwarded-for header in forwarded requests: forwards (pass), adds, or removes the HTTP header.")    
    header_x_forwarded_client_cert: Literal["pass", "add", "remove"] | None = Field(default="pass", description="Action to take on the HTTP x-forwarded-client-cert header in forwarded requests: forwards (pass), adds, or removes the HTTP header.")    
    header_front_end_https: Literal["pass", "add", "remove"] | None = Field(default="pass", description="Action to take on the HTTP front-end-HTTPS header in forwarded requests: forwards (pass), adds, or removes the HTTP header.")    
    header_x_authenticated_user: Literal["pass", "add", "remove"] | None = Field(default="pass", description="Action to take on the HTTP x-authenticated-user header in forwarded requests: forwards (pass), adds, or removes the HTTP header.")    
    header_x_authenticated_groups: Literal["pass", "add", "remove"] | None = Field(default="pass", description="Action to take on the HTTP x-authenticated-groups header in forwarded requests: forwards (pass), adds, or removes the HTTP header.")    
    strip_encoding: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable stripping unsupported encoding from the request header.")    
    log_header_change: Literal["enable", "disable"] | None = Field(default="disable", description="Enable/disable logging HTTP header changes.")    
    headers: list[Headers] = Field(default=None, description="Configure HTTP forwarded requests headers.")    
    # ========================================================================
    # Custom Validators
    # ========================================================================
    
    # ========================================================================
    # Helper Methods
    # ========================================================================
    
    def to_fortios_dict(self) -> dict[str, Any]:
        """
        Convert model to FortiOS API payload format.
        
        Returns:
            Dict suitable for POST/PUT operations
        """
        # Export with exclude_none to avoid sending null values
        return self.model_dump(exclude_none=True, by_alias=True)
    
    @classmethod
    def from_fortios_response(cls, data: dict[str, Any]) -> "":
        """
        Create model instance from FortiOS API response.
        
        Args:
            data: Response data from API
            
        Returns:
            Validated model instance
        """
        return cls(**data)

# ============================================================================
# Type Aliases for Convenience
# ============================================================================

Dict = dict[str, Any]  # For backward compatibility

# ============================================================================
# Module Exports
# ============================================================================

__all__ = [
    "ProfileModel",    "ProfileHeaders",]


# ============================================================================
# Generated by hfortix generator v0.6.0
# Schema: 1.7.0
# Generated: 2026-01-09T09:47:41.125766Z
# ============================================================================


"""Type stubs for SERVICE category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .category import Category, CategoryDictMode, CategoryObjectMode
    from .custom import Custom, CustomDictMode, CustomObjectMode
    from .group import Group, GroupDictMode, GroupObjectMode

__all__ = [
    "Category",
    "Custom",
    "Group",
    "ServiceDictMode",
    "ServiceObjectMode",
]

class ServiceDictMode:
    """SERVICE API category for dict response mode.
    
    This class is returned when the client is instantiated with response_mode="dict" (default).
    All endpoints return dict/TypedDict responses by default.
    """
    
    category: CategoryDictMode
    custom: CustomDictMode
    group: GroupDictMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize service category with HTTP client."""
        ...


class ServiceObjectMode:
    """SERVICE API category for object response mode.
    
    This class is returned when the client is instantiated with response_mode="object".
    All endpoints return FortiObject responses by default.
    """
    
    category: CategoryObjectMode
    custom: CustomObjectMode
    group: GroupObjectMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize service category with HTTP client."""
        ...


# Base class for backwards compatibility
class Service:
    """SERVICE API category."""
    
    category: Category
    custom: Custom
    group: Group

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize service category with HTTP client."""
        ...



"""Type stubs for SYSTEM category."""

from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from hfortix_core.http.interface import IHTTPClient
    from .acme_certificate_status import AcmeCertificateStatus, AcmeCertificateStatusDictMode, AcmeCertificateStatusObjectMode
    from .acquired_dns import AcquiredDns, AcquiredDnsDictMode, AcquiredDnsObjectMode
    from .available_certificates import AvailableCertificates, AvailableCertificatesDictMode, AvailableCertificatesObjectMode
    from .check_port_availability import CheckPortAvailability, CheckPortAvailabilityDictMode, CheckPortAvailabilityObjectMode
    from .current_admins import CurrentAdmins, CurrentAdminsDictMode, CurrentAdminsObjectMode
    from .global_resources import GlobalResources, GlobalResourcesDictMode, GlobalResourcesObjectMode
    from .global_search import GlobalSearch, GlobalSearchDictMode, GlobalSearchObjectMode
    from .ha_backup_hb_used import HaBackupHbUsed, HaBackupHbUsedDictMode, HaBackupHbUsedObjectMode
    from .ha_checksums import HaChecksums, HaChecksumsDictMode, HaChecksumsObjectMode
    from .ha_history import HaHistory, HaHistoryDictMode, HaHistoryObjectMode
    from .ha_hw_interface import HaHwInterface, HaHwInterfaceDictMode, HaHwInterfaceObjectMode
    from .ha_nonsync_checksums import HaNonsyncChecksums, HaNonsyncChecksumsDictMode, HaNonsyncChecksumsObjectMode
    from .ha_statistics import HaStatistics, HaStatisticsDictMode, HaStatisticsObjectMode
    from .ha_table_checksums import HaTableChecksums, HaTableChecksumsDictMode, HaTableChecksumsObjectMode
    from .interface_connected_admins_info import InterfaceConnectedAdminsInfo, InterfaceConnectedAdminsInfoDictMode, InterfaceConnectedAdminsInfoObjectMode
    from .ipconf import Ipconf, IpconfDictMode, IpconfObjectMode
    from .link_monitor import LinkMonitor, LinkMonitorDictMode, LinkMonitorObjectMode
    from .modem3g import Modem3g, Modem3gDictMode, Modem3gObjectMode
    from .monitor_sensor import MonitorSensor, MonitorSensorDictMode, MonitorSensorObjectMode
    from .resolve_fqdn import ResolveFqdn, ResolveFqdnDictMode, ResolveFqdnObjectMode
    from .running_processes import RunningProcesses, RunningProcessesDictMode, RunningProcessesObjectMode
    from .sensor_info import SensorInfo, SensorInfoDictMode, SensorInfoObjectMode
    from .status import Status, StatusDictMode, StatusObjectMode
    from .storage import Storage, StorageDictMode, StorageObjectMode
    from .timezone import Timezone, TimezoneDictMode, TimezoneObjectMode
    from .trusted_cert_authorities import TrustedCertAuthorities, TrustedCertAuthoritiesDictMode, TrustedCertAuthoritiesObjectMode
    from .vdom_link import VdomLink, VdomLinkDictMode, VdomLinkObjectMode
    from .vdom_resource import VdomResource, VdomResourceDictMode, VdomResourceObjectMode
    from .vm_information import VmInformation, VmInformationDictMode, VmInformationObjectMode
    from .admin import AdminDictMode, AdminObjectMode
    from .api_user import ApiUser
    from .automation_action import AutomationAction
    from .automation_stitch import AutomationStitch
    from .available_interfaces import AvailableInterfaces
    from .botnet import Botnet
    from .botnet_domains import BotnetDomains
    from .central_management import CentralManagement
    from .certificate import CertificateDictMode, CertificateObjectMode
    from .change_password import ChangePassword
    from .cluster import ClusterDictMode, ClusterObjectMode
    from .com_log import ComLog
    from .config import ConfigDictMode, ConfigObjectMode
    from .config_error_log import ConfigErrorLog
    from .config_revision import ConfigRevision
    from .config_script import ConfigScript
    from .config_sync import ConfigSync
    from .crash_log import CrashLog
    from .csf import Csf
    from .debug import DebugDictMode, DebugObjectMode
    from .dhcp import Dhcp
    from .dhcp6 import Dhcp6DictMode, Dhcp6ObjectMode
    from .disconnect_admins import DisconnectAdmins
    from .external_resource import ExternalResource
    from .firmware import Firmware
    from .fortiguard import FortiguardDictMode, FortiguardObjectMode
    from .fortimanager import FortimanagerDictMode, FortimanagerObjectMode
    from .fsck import FsckDictMode, FsckObjectMode
    from .ha_peer import HaPeer
    from .hscalefw_license import HscalefwLicense
    from .interface import Interface
    from .ipam import IpamDictMode, IpamObjectMode
    from .logdisk import LogdiskDictMode, LogdiskObjectMode
    from .lte_modem import LteModem
    from .modem import Modem
    from .modem5g import Modem5gDictMode, Modem5gObjectMode
    from .ntp import NtpDictMode, NtpObjectMode
    from .object import ObjectDictMode, ObjectObjectMode
    from .os import OsDictMode, OsObjectMode
    from .password_policy_conform import PasswordPolicyConform
    from .performance import PerformanceDictMode, PerformanceObjectMode
    from .private_data_encryption import PrivateDataEncryption
    from .process import ProcessDictMode, ProcessObjectMode
    from .resource import ResourceDictMode, ResourceObjectMode
    from .sandbox import SandboxDictMode, SandboxObjectMode
    from .sdn_connector import SdnConnector
    from .time import Time
    from .traffic_history import TrafficHistory
    from .upgrade_report import UpgradeReport
    from .usb_device import UsbDevice
    from .usb_log import UsbLog
    from .vmlicense import VmlicenseDictMode, VmlicenseObjectMode

__all__ = [
    "AcmeCertificateStatus",
    "AcquiredDns",
    "AvailableCertificates",
    "CheckPortAvailability",
    "CurrentAdmins",
    "GlobalResources",
    "GlobalSearch",
    "HaBackupHbUsed",
    "HaChecksums",
    "HaHistory",
    "HaHwInterface",
    "HaNonsyncChecksums",
    "HaStatistics",
    "HaTableChecksums",
    "InterfaceConnectedAdminsInfo",
    "Ipconf",
    "LinkMonitor",
    "Modem3g",
    "MonitorSensor",
    "ResolveFqdn",
    "RunningProcesses",
    "SensorInfo",
    "Status",
    "Storage",
    "Timezone",
    "TrustedCertAuthorities",
    "VdomLink",
    "VdomResource",
    "VmInformation",
    "SystemDictMode",
    "SystemObjectMode",
]

class SystemDictMode:
    """SYSTEM API category for dict response mode.
    
    This class is returned when the client is instantiated with response_mode="dict" (default).
    All endpoints return dict/TypedDict responses by default.
    """
    
    admin: AdminDictMode
    api_user: ApiUser
    automation_action: AutomationAction
    automation_stitch: AutomationStitch
    available_interfaces: AvailableInterfaces
    botnet: Botnet
    botnet_domains: BotnetDomains
    central_management: CentralManagement
    certificate: CertificateDictMode
    change_password: ChangePassword
    cluster: ClusterDictMode
    com_log: ComLog
    config: ConfigDictMode
    config_error_log: ConfigErrorLog
    config_revision: ConfigRevision
    config_script: ConfigScript
    config_sync: ConfigSync
    crash_log: CrashLog
    csf: Csf
    debug: DebugDictMode
    dhcp: Dhcp
    dhcp6: Dhcp6DictMode
    disconnect_admins: DisconnectAdmins
    external_resource: ExternalResource
    firmware: Firmware
    fortiguard: FortiguardDictMode
    fortimanager: FortimanagerDictMode
    fsck: FsckDictMode
    ha_peer: HaPeer
    hscalefw_license: HscalefwLicense
    interface: Interface
    ipam: IpamDictMode
    logdisk: LogdiskDictMode
    lte_modem: LteModem
    modem: Modem
    modem5g: Modem5gDictMode
    ntp: NtpDictMode
    object: ObjectDictMode
    os: OsDictMode
    password_policy_conform: PasswordPolicyConform
    performance: PerformanceDictMode
    private_data_encryption: PrivateDataEncryption
    process: ProcessDictMode
    resource: ResourceDictMode
    sandbox: SandboxDictMode
    sdn_connector: SdnConnector
    time: Time
    traffic_history: TrafficHistory
    upgrade_report: UpgradeReport
    usb_device: UsbDevice
    usb_log: UsbLog
    vmlicense: VmlicenseDictMode
    acme_certificate_status: AcmeCertificateStatusDictMode
    acquired_dns: AcquiredDnsDictMode
    available_certificates: AvailableCertificatesDictMode
    check_port_availability: CheckPortAvailabilityDictMode
    current_admins: CurrentAdminsDictMode
    global_resources: GlobalResourcesDictMode
    global_search: GlobalSearchDictMode
    ha_backup_hb_used: HaBackupHbUsedDictMode
    ha_checksums: HaChecksumsDictMode
    ha_history: HaHistoryDictMode
    ha_hw_interface: HaHwInterfaceDictMode
    ha_nonsync_checksums: HaNonsyncChecksumsDictMode
    ha_statistics: HaStatisticsDictMode
    ha_table_checksums: HaTableChecksumsDictMode
    interface_connected_admins_info: InterfaceConnectedAdminsInfoDictMode
    ipconf: IpconfDictMode
    link_monitor: LinkMonitorDictMode
    modem3g: Modem3gDictMode
    monitor_sensor: MonitorSensorDictMode
    resolve_fqdn: ResolveFqdnDictMode
    running_processes: RunningProcessesDictMode
    sensor_info: SensorInfoDictMode
    status: StatusDictMode
    storage: StorageDictMode
    timezone: TimezoneDictMode
    trusted_cert_authorities: TrustedCertAuthoritiesDictMode
    vdom_link: VdomLinkDictMode
    vdom_resource: VdomResourceDictMode
    vm_information: VmInformationDictMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize system category with HTTP client."""
        ...


class SystemObjectMode:
    """SYSTEM API category for object response mode.
    
    This class is returned when the client is instantiated with response_mode="object".
    All endpoints return FortiObject responses by default.
    """
    
    admin: AdminObjectMode
    api_user: ApiUser
    automation_action: AutomationAction
    automation_stitch: AutomationStitch
    available_interfaces: AvailableInterfaces
    botnet: Botnet
    botnet_domains: BotnetDomains
    central_management: CentralManagement
    certificate: CertificateObjectMode
    change_password: ChangePassword
    cluster: ClusterObjectMode
    com_log: ComLog
    config: ConfigObjectMode
    config_error_log: ConfigErrorLog
    config_revision: ConfigRevision
    config_script: ConfigScript
    config_sync: ConfigSync
    crash_log: CrashLog
    csf: Csf
    debug: DebugObjectMode
    dhcp: Dhcp
    dhcp6: Dhcp6ObjectMode
    disconnect_admins: DisconnectAdmins
    external_resource: ExternalResource
    firmware: Firmware
    fortiguard: FortiguardObjectMode
    fortimanager: FortimanagerObjectMode
    fsck: FsckObjectMode
    ha_peer: HaPeer
    hscalefw_license: HscalefwLicense
    interface: Interface
    ipam: IpamObjectMode
    logdisk: LogdiskObjectMode
    lte_modem: LteModem
    modem: Modem
    modem5g: Modem5gObjectMode
    ntp: NtpObjectMode
    object: ObjectObjectMode
    os: OsObjectMode
    password_policy_conform: PasswordPolicyConform
    performance: PerformanceObjectMode
    private_data_encryption: PrivateDataEncryption
    process: ProcessObjectMode
    resource: ResourceObjectMode
    sandbox: SandboxObjectMode
    sdn_connector: SdnConnector
    time: Time
    traffic_history: TrafficHistory
    upgrade_report: UpgradeReport
    usb_device: UsbDevice
    usb_log: UsbLog
    vmlicense: VmlicenseObjectMode
    acme_certificate_status: AcmeCertificateStatusObjectMode
    acquired_dns: AcquiredDnsObjectMode
    available_certificates: AvailableCertificatesObjectMode
    check_port_availability: CheckPortAvailabilityObjectMode
    current_admins: CurrentAdminsObjectMode
    global_resources: GlobalResourcesObjectMode
    global_search: GlobalSearchObjectMode
    ha_backup_hb_used: HaBackupHbUsedObjectMode
    ha_checksums: HaChecksumsObjectMode
    ha_history: HaHistoryObjectMode
    ha_hw_interface: HaHwInterfaceObjectMode
    ha_nonsync_checksums: HaNonsyncChecksumsObjectMode
    ha_statistics: HaStatisticsObjectMode
    ha_table_checksums: HaTableChecksumsObjectMode
    interface_connected_admins_info: InterfaceConnectedAdminsInfoObjectMode
    ipconf: IpconfObjectMode
    link_monitor: LinkMonitorObjectMode
    modem3g: Modem3gObjectMode
    monitor_sensor: MonitorSensorObjectMode
    resolve_fqdn: ResolveFqdnObjectMode
    running_processes: RunningProcessesObjectMode
    sensor_info: SensorInfoObjectMode
    status: StatusObjectMode
    storage: StorageObjectMode
    timezone: TimezoneObjectMode
    trusted_cert_authorities: TrustedCertAuthoritiesObjectMode
    vdom_link: VdomLinkObjectMode
    vdom_resource: VdomResourceObjectMode
    vm_information: VmInformationObjectMode

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize system category with HTTP client."""
        ...


# Base class for backwards compatibility
class System:
    """SYSTEM API category."""
    
    admin: Admin
    api_user: ApiUser
    automation_action: AutomationAction
    automation_stitch: AutomationStitch
    available_interfaces: AvailableInterfaces
    botnet: Botnet
    botnet_domains: BotnetDomains
    central_management: CentralManagement
    certificate: Certificate
    change_password: ChangePassword
    cluster: Cluster
    com_log: ComLog
    config: Config
    config_error_log: ConfigErrorLog
    config_revision: ConfigRevision
    config_script: ConfigScript
    config_sync: ConfigSync
    crash_log: CrashLog
    csf: Csf
    debug: Debug
    dhcp: Dhcp
    dhcp6: Dhcp6
    disconnect_admins: DisconnectAdmins
    external_resource: ExternalResource
    firmware: Firmware
    fortiguard: Fortiguard
    fortimanager: Fortimanager
    fsck: Fsck
    ha_peer: HaPeer
    hscalefw_license: HscalefwLicense
    interface: Interface
    ipam: Ipam
    logdisk: Logdisk
    lte_modem: LteModem
    modem: Modem
    modem5g: Modem5g
    ntp: Ntp
    object: Object
    os: Os
    password_policy_conform: PasswordPolicyConform
    performance: Performance
    private_data_encryption: PrivateDataEncryption
    process: Process
    resource: Resource
    sandbox: Sandbox
    sdn_connector: SdnConnector
    time: Time
    traffic_history: TrafficHistory
    upgrade_report: UpgradeReport
    usb_device: UsbDevice
    usb_log: UsbLog
    vmlicense: Vmlicense
    acme_certificate_status: AcmeCertificateStatus
    acquired_dns: AcquiredDns
    available_certificates: AvailableCertificates
    check_port_availability: CheckPortAvailability
    current_admins: CurrentAdmins
    global_resources: GlobalResources
    global_search: GlobalSearch
    ha_backup_hb_used: HaBackupHbUsed
    ha_checksums: HaChecksums
    ha_history: HaHistory
    ha_hw_interface: HaHwInterface
    ha_nonsync_checksums: HaNonsyncChecksums
    ha_statistics: HaStatistics
    ha_table_checksums: HaTableChecksums
    interface_connected_admins_info: InterfaceConnectedAdminsInfo
    ipconf: Ipconf
    link_monitor: LinkMonitor
    modem3g: Modem3g
    monitor_sensor: MonitorSensor
    resolve_fqdn: ResolveFqdn
    running_processes: RunningProcesses
    sensor_info: SensorInfo
    status: Status
    storage: Storage
    timezone: Timezone
    trusted_cert_authorities: TrustedCertAuthorities
    vdom_link: VdomLink
    vdom_resource: VdomResource
    vm_information: VmInformation

    def __init__(self, client: IHTTPClient, vdom: str | None = None) -> None:
        """Initialize system category with HTTP client."""
        ...
